@@ -17,7 +17,7 @@ from pmb.config.sudo import which_sudo
 #
 # Exported variables (internal configuration)
 #
-version = "1.41.0"
+version = "1.42.0"
 pmb_src = os.path.normpath(os.path.realpath(__file__) + "/../../..")
 apk_keys_path = pmb_src + "/pmb/data/keys"
 arch_native = pmb.parse.arch.alpine_native()
@@ -70,6 +70,7 @@ config_keys = ["aports",
                "nonfree_firmware",
                "nonfree_userland",
                "ssh_keys",
+               "ssh_key_glob",
                "timezone",
                "ui",
                "ui_extras",
@@ -77,7 +78,8 @@ config_keys = ["aports",
                "work",
                "boot_size",
                "extra_space",
-               "sudo_timer"]
+               "sudo_timer",
+               "qemu_redir_stdio"]
 
 # Config file/commandline default values
 # $WORK gets replaced with the actual value for args.work (which may be
@@ -111,6 +113,7 @@ defaults = {
     "nonfree_userland": False,
     "port_distccd": "33632",
     "ssh_keys": False,
+    "ssh_key_glob": "~/.ssh/id_*.pub",
     "timezone": "GMT",
     "ui": "weston",
     "ui_extras": False,
@@ -118,7 +121,8 @@ defaults = {
     "work": os.path.expanduser("~") + "/.local/var/pmbootstrap",
     "boot_size": "256",
     "extra_space": "0",
-    "sudo_timer": False
+    "sudo_timer": False,
+    "qemu_redir_stdio": False
 }
 
 
@@ -164,7 +168,8 @@ locales = [
 ]
 
 # Supported filesystems and their fstools packages
-filesystems = {"ext2": "e2fsprogs",
+filesystems = {"btrfs": "btrfs-progs",
+               "ext2": "e2fsprogs",
                "ext4": "e2fsprogs",
                "f2fs": "f2fs-tools",
                "fat16": "dosfstools",
@@ -210,6 +215,7 @@ chroot_mount_bind = {
     "$WORK/cache_rust": "/mnt/pmbootstrap-rust",
     "$WORK/config_abuild": "/mnt/pmbootstrap-abuild-config",
     "$WORK/config_apk_keys": "/etc/apk/keys",
+    "$WORK/images_netboot": "/mnt/pmbootstrap-netboot",
     "$WORK/packages/$CHANNEL": "/mnt/pmbootstrap-packages",
 }
 
@@ -562,6 +568,15 @@ necessary_kconfig_options_zram = {
     },
 }
 
+# Necessary netboot kernel config options
+necessary_kconfig_options_netboot = {
+    ">=0.0.0": {  # all versions
+        "all": {  # all arches
+            "BLK_DEV_NBD": True,
+        }
+    },
+}
+
 #
 # PARSE
 #
@@ -697,8 +712,12 @@ deviceinfo_attributes = [
     "sd_embed_firmware_step_size",
     "partition_blacklist",
     "boot_part_start",
+    "partition_type",
     "root_filesystem",
     "flash_kernel_on_update",
+    "cgpt_kpart",
+    "cgpt_kpart_start",
+    "cgpt_kpart_size",
 
     # weston
     "weston_pixman_type",
@@ -749,7 +768,7 @@ flash_methods = [
     "0xffff",
     "fastboot",
     "heimdall",
-    "none"
+    "none",
     "rkdeveloptool",
     "uuu",
 ]
@@ -883,11 +902,17 @@ flashers = {
         },
     },
     "rkdeveloptool": {
+        "split": True,
         "depends": ["rkdeveloptool"],
         "actions": {
-            "list_devices": [["rkdeveloptool", "ld"]],
+            "list_devices": [["rkdeveloptool", "list"]],
             "flash_rootfs": [
-                ["rkdeveloptool", "wl", "0", "$IMAGE"]
+                ["rkdeveloptool", "write-partition", "$PARTITION_SYSTEM",
+                    "$IMAGE_SPLIT_ROOT"]
+            ],
+            "flash_kernel": [
+                ["rkdeveloptool", "write-partition", "$PARTITION_KERNEL",
+                    "$IMAGE_SPLIT_BOOT"]
             ],
         },
     }
