@@ -228,6 +228,19 @@ def setup_login_chpasswd_user_from_arg(args, suffix):
     os.unlink(path_outside)
 
 
+def is_root_locked(args, suffix):
+    """
+    Figure out from /etc/shadow if root is already locked. The output of this
+    is stored in the log, so use grep to only log the line for root, not the
+    line for the user which contains a hash of the user's password.
+
+    :param suffix: either rootfs_{args.device} or installer_{args.device}
+    """
+    shadow_root = pmb.chroot.root(args, ["grep", "^root:!:", "/etc/shadow"],
+                                  suffix, output_return=True, check=False)
+    return shadow_root.startswith("root:!:")
+
+
 def setup_login(args, suffix):
     """
     Loop until the password for user has been set successfully, and disable
@@ -250,10 +263,13 @@ def setup_login(args, suffix):
                 except RuntimeError:
                     logging.info("WARNING: Failed to set the password. Try it"
                                  " one more time.")
-                    pass
 
     # Disable root login
-    pmb.chroot.root(args, ["passwd", "-l", "root"], suffix)
+    if is_root_locked(args, suffix):
+        logging.debug(f"({suffix}) root is already locked")
+    else:
+        logging.debug(f"({suffix}) locking root")
+        pmb.chroot.root(args, ["passwd", "-l", "root"], suffix)
 
 
 def copy_ssh_keys(args):
@@ -263,7 +279,7 @@ def copy_ssh_keys(args):
     if not args.ssh_keys:
         return
     keys = []
-    for key in glob.glob(os.path.expanduser("~/.ssh/id_*.pub")):
+    for key in glob.glob(os.path.expanduser(args.ssh_key_glob)):
         with open(key, "r") as infile:
             keys += infile.readlines()
 
@@ -537,6 +553,22 @@ def embed_firmware(args, suffix):
                                "bs=" + str(step), "seek=" + str(offset)])
 
 
+def write_cgpt_kpart(args, layout, suffix):
+    """
+    Write the kernel to the ChromeOS kernel partition.
+
+    :param layout: partition layout from get_partition_layout()
+    :param suffix: of the chroot, which holds the image file to be flashed
+    """
+    if not args.deviceinfo["cgpt_kpart"]:
+        return
+
+    device_rootfs = mount_device_rootfs(args, suffix)
+    filename = f"{device_rootfs}{args.deviceinfo['cgpt_kpart']}"
+    pmb.chroot.root(
+        args, ["dd", f"if={filename}", f"of=/dev/installp{layout['kernel']}"])
+
+
 def sanity_check_sdcard(args):
     device = args.sdcard
     device_name = os.path.basename(device)
@@ -591,6 +623,31 @@ def sanity_check_ondev_version(args):
                            f" / in the binary packages has version {ver_pkg}.")
 
 
+def get_partition_layout(reserve, kernel):
+    """
+    :param reserve: create an empty partition between root and boot (pma#463)
+    :param kernel: create a separate kernel partition before all other
+                   partitions, e.g. for the ChromeOS devices with cgpt
+    :returns: the partition layout, e.g. without reserve and kernel:
+              {"kernel": None, "boot": 1, "reserve": None, "root": 2}
+    """
+    ret = {}
+    ret["kernel"] = None
+    ret["boot"] = 1
+    ret["reserve"] = None
+    ret["root"] = 2
+
+    if kernel:
+        ret["kernel"] = 1
+        ret["boot"] += 1
+        ret["root"] += 1
+
+    if reserve:
+        ret["reserve"] = ret["root"]
+        ret["root"] += 1
+    return ret
+
+
 def install_system_image(args, size_reserve, suffix, step, steps,
                          boot_label="pmOS_boot", root_label="pmOS_root",
                          split=False, sdcard=None):
@@ -609,16 +666,20 @@ def install_system_image(args, size_reserve, suffix, step, steps,
     logging.info(f"*** ({step}/{steps}) PREPARE INSTALL BLOCKDEVICE ***")
     pmb.chroot.shutdown(args, True)
     (size_boot, size_root) = get_subpartitions_size(args, suffix)
+    layout = get_partition_layout(size_reserve, args.deviceinfo["cgpt_kpart"])
     if not args.rsync:
         pmb.install.blockdevice.create(args, size_boot, size_root,
                                        size_reserve, split, sdcard)
         if not split:
-            pmb.install.partition(args, size_boot, size_reserve)
+            if args.deviceinfo["cgpt_kpart"]:
+                pmb.install.partition_cgpt(
+                    args, layout, size_boot, size_reserve)
+            else:
+                pmb.install.partition(args, layout, size_boot, size_reserve)
     if not split:
-        root_id = 3 if size_reserve else 2
-        pmb.install.partitions_mount(args, root_id, sdcard)
+        pmb.install.partitions_mount(args, layout, sdcard)
 
-    pmb.install.format(args, size_reserve, boot_label, root_label, sdcard)
+    pmb.install.format(args, layout, boot_label, root_label, sdcard)
 
     # Just copy all the files
     logging.info(f"*** ({step + 1}/{steps}) FILL INSTALL BLOCKDEVICE ***")
@@ -627,10 +688,11 @@ def install_system_image(args, size_reserve, suffix, step, steps,
     configure_apk(args)
     copy_ssh_keys(args)
 
-    # Don't try to embed firmware on split images since there's no
+    # Don't try to embed firmware and cgpt on split images since there's no
     # place to put it and it will end up in /dev of the chroot instead
     if not split:
         embed_firmware(args, suffix)
+        write_cgpt_kpart(args, layout, suffix)
 
     if sdcard:
         logging.info("Unmounting SD card (this may take a while "
