@@ -162,7 +162,7 @@ def arguments_install(subparser):
     # Other
     group = ret.add_argument_group("other optional arguments")
     group.add_argument("--filesystem", help="root filesystem type",
-                       choices=["ext4", "f2fs"])
+                       choices=["ext4", "f2fs", "btrfs"])
 
 
 def arguments_export(subparser):
@@ -456,6 +456,8 @@ def arguments_kconfig(subparser):
                        help="check options needed for containers too")
     check.add_argument("--zram", action="store_true", help="check"
                        " options needed for zram support too")
+    check.add_argument("--netboot", action="store_true", help="check"
+                       " options needed for netboooting too")
     add_kernel_arg(check)
 
     # "pmbootstrap kconfig edit"
@@ -508,6 +510,19 @@ def arguments_status(subparser):
     return ret
 
 
+def arguments_netboot(subparser):
+    ret = subparser.add_parser("netboot",
+                               help="launch nbd server with pmOS rootfs")
+    sub = ret.add_subparsers(dest="action_netboot")
+    sub.required = True
+
+    start = sub.add_parser("serve", help="start nbd server")
+    start.add_argument("--replace", action="store_true",
+                       help="replace stored netboot image")
+
+    return ret
+
+
 def package_completer(prefix, action, parser=None, parsed_args=None):
     args = parsed_args
     pmb.config.merge_with_args(args)
@@ -646,6 +661,7 @@ def arguments():
     arguments_kconfig(sub)
     arguments_export(sub)
     arguments_sideload(sub)
+    arguments_netboot(sub)
     arguments_flasher(sub)
     arguments_initfs(sub)
     arguments_qemu(sub)
@@ -682,6 +698,8 @@ def arguments():
                      dest="pkgs_local_mismatch",
                      help="also delete locally compiled packages without"
                      " existing aport of same version")
+    zap.add_argument("-n", "--netboot", action="store_true",
+                     help="also delete stored images for netboot")
     zap.add_argument("-o", "--pkgs-online-mismatch", action="store_true",
                      dest="pkgs_online_mismatch",
                      help="also delete outdated packages from online mirrors"
